@@ -54,10 +54,10 @@ pub mod octo_print_backup;
 pub use self::octo_print_backup::OctoPrintBackup;
 pub mod octo_print_event;
 pub use self::octo_print_event::OctoPrintEvent;
-pub mod octo_print_event_event_name_enum;
-pub use self::octo_print_event_event_name_enum::OctoPrintEventEventNameEnum;
-pub mod octo_print_event_model_enum;
-pub use self::octo_print_event_model_enum::OctoPrintEventModelEnum;
+pub mod octo_print_event_model;
+pub use self::octo_print_event_model::OctoPrintEventModel;
+pub mod octo_print_event_name;
+pub use self::octo_print_event_name::OctoPrintEventName;
 pub mod octo_print_event_request;
 pub use self::octo_print_event_request::OctoPrintEventRequest;
 pub mod octo_print_install;
@@ -72,6 +72,8 @@ pub mod octo_printer_profile;
 pub use self::octo_printer_profile::OctoPrinterProfile;
 pub mod octo_printer_profile_request;
 pub use self::octo_printer_profile_request::OctoPrinterProfileRequest;
+pub mod os_edition;
+pub use self::os_edition::OsEdition;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
 pub mod paginated_cloudiot_device_list;
@@ -166,10 +168,10 @@ pub mod user_request;
 pub use self::user_request::UserRequest;
 pub mod web_rtc_command;
 pub use self::web_rtc_command::WebRtcCommand;
-pub mod web_rtc_command_event_name_enum;
-pub use self::web_rtc_command_event_name_enum::WebRtcCommandEventNameEnum;
-pub mod web_rtc_command_model_enum;
-pub use self::web_rtc_command_model_enum::WebRtcCommandModelEnum;
+pub mod web_rtc_command_model;
+pub use self::web_rtc_command_model::WebRtcCommandModel;
+pub mod web_rtc_command_name;
+pub use self::web_rtc_command_name::WebRtcCommandName;
 pub mod web_rtc_command_request;
 pub use self::web_rtc_command_request::WebRtcCommandRequest;
 pub mod web_rtc_event;
